# PolarsAI
A library converted from PandasAI to run with the Python Polars library
## Authors
- [Aaron McClendon (Aimpoint Digital)](https://www.github.com/apd-smcclendon)
## Installation
Install my-project with pip
```bash
  pip install polarsai
```
## Requirements
* numpy